@@ -104,7 +104,7 @@ class Event(Component):
         component used to represent a meeting that will also be opaque to
         searches for busy time:
 
-        .. code-block:: text
+        .. code-block:: ics
 
             BEGIN:VEVENT
             UID:19970901T130000Z-123401@example.com
@@ -120,7 +120,7 @@ class Event(Component):
         used to represent a reminder that will not be opaque, but rather
         transparent, to searches for busy time:
 
-        .. code-block:: text
+        .. code-block:: ics
 
             BEGIN:VEVENT
             UID:19970901T130000Z-123402@example.com
@@ -136,7 +136,7 @@ class Event(Component):
         The following is an example of the "VEVENT" calendar component
         used to represent an anniversary that will occur annually:
 
-        .. code-block:: text
+        .. code-block:: ics
 
             BEGIN:VEVENT
             UID:19970901T130000Z-123403@example.com
@@ -155,7 +155,7 @@ class Event(Component):
         set to July 9th, 2007, since the "DTEND" property specifies the
         non-inclusive end of the event.
 
-        .. code-block:: text
+        .. code-block:: ics
 
             BEGIN:VEVENT
             UID:20070423T123432Z-541111@example.com
@@ -424,6 +424,7 @@ class Event(Component):
     attendees = attendees_property
     images = images_property
     conferences = conferences_property
+    from icalendar.attr import RECURRENCE_ID
 
     @classmethod
     def new(
@@ -445,6 +446,7 @@ class Event(Component):
         location: str | None = None,
         organizer: vCalAddress | str | None = None,
         priority: int | None = None,
+        recurrence_id: date | datetime | None = None,
         refids: list[str] | str | None = None,
         related_to: RELATED_TO_TYPE_SETTER = None,
         sequence: int | None = None,
@@ -476,6 +478,7 @@ class Event(Component):
             location: The :attr:`location` of the event.
             organizer: The :attr:`organizer` of the event.
             priority: The :attr:`priority` of the event.
+            recurrence_id: The :attr:`RECURRENCE_ID` of the event.
             refids: :attr:`~icalendar.Component.refids` of the event.
             related_to: :attr:`~icalendar.Component.related_to` of the event.
             sequence: The :attr:`sequence` of the event.
@@ -526,6 +529,7 @@ class Event(Component):
         event.status = status
         event.attendees = attendees
         event.conferences = conferences
+        event.RECURRENCE_ID = recurrence_id
 
         if cls._validate_new:
             cls._validate_start_and_end(start, end)
