@@ -412,6 +412,24 @@ new_test_cases = [
         True,
         "set the end",
     ),
+    (
+        {Event, Todo, Journal, Available},
+        "RECURRENCE_ID",
+        "RECURRENCE-ID",
+        datetime(2025, 4, 28, 16, 5, tzinfo=ZoneInfo("UTC")),
+        datetime(2025, 4, 28, 16, 5, tzinfo=ZoneInfo("UTC")),
+        True,
+        "set the recurrence_id",
+    ),
+    (
+        {Event, Todo, Journal, Available},
+        "RECURRENCE_ID",
+        "RECURRENCE-ID",
+        None,
+        None,
+        False,
+        "no recurrence_id by default",
+    ),
     (
         {Todo, Event, Calendar, Journal},
         "color",
